#!/bin/bash

echo
echo "***********************************************************"
echo "**** Tivoli Storage Manager Suite for Unified Recovery ****"
echo "****           Capacity Measurement Tool               ****"
echo "****       For Use with V6 or later Servers            ****"
echo "******************** ( version: 1.9 ) *********************"
echo

function print_usage()
{
  echo
  echo Syntax error ...
  echo Usage: %~0 -tsmcpath=path -tsmopt=dsmopt -tsmadmin=admin -tsmpass=admin -ptclipath=path -ptaddr=address -ptuser=user -ptpass=pass
  exit 1
}

PRARNUM=$#

#echo Replace "=" by " " in the input parameters
TEMP=`echo $* | sed 's/=/ /g'`
if [ $? != 0 ] ; then echo "Terminating..." >&2 ; exit 1 ; fi
eval set -- "$TEMP"

while true ; do
  case "$1" in
    -tsmcpath) 
      DSMADMCPATH=$2 ; shift 2 ;;
    -tsmopt) 
      DSMOPTFILE=$2 ; shift 2 ;;
    -tsmadmin) 
      DSMADMIN=$2 ; shift 2 ;;
    -tsmpass) 
      DSMPASS=$2 ; shift 2 ;;
    -ptclipath) 
      PTCLIPATH=$2 ; shift 2 ;;
    -ptaddr) 
      PTIPADDR=$2 ; shift 2 ;;
    -ptuser) 
      PTUSER=$2 ; shift 2 ;;
    -ptpass) 
      PTPASS=$2 ; shift 2 ;;
    *)
      break ;;
  esac
done

# Verify system requirement
OSNAME=`uname`
if [ "$OSNAME"x != "Linux"x ]
then
  echo The Capacity Measurement Tool must be run on a Microsoft Windows or Linux computer, and the PortectTIER Manager command-line tool and TSM command-line administrative client must be installed on that system.
  echo Exiting ...
  exit 1
fi

# Validate existence of dmsamdc and ptcli
echo Validating input parameters ... 

if [ -f $DSMADMCPATH/dsmadmc ]
then
  echo validating -tsmcpath path -- OK.
else
  echo validating -tsmcpath path $DSMADMCPATH/dsmadmc -- File does not exist.
  if [ -f /opt/tivoli/tsm/client/ba/bin/dsmadmc ]
  then
    echo validating -tsmcpath default path /opt/tivoli/tsm/client/ba/bin/dsmadmc -- OK.
    set DSMADMCPATH=/opt/tivoli/tsm/client/ba/bin   
  else
    echo validating -tsmcpath default path /opt/tivoli/tsm/client/ba/bin/dsmadmc -- File does not exist.
    echo ACTION NEEDED: Cannot locate dsmadmc . Please ensure TSM command-line administrative client is installed on this system and the path is correct and then rerun. 
    echo Exiting ...
    exit 1
  fi
fi

if [ -f $DSMOPTFILE ]
then
  echo validating -tsmopt path -- OK.
else
  echo validating -tsmopt path $DSMADMCPATH/dsmadmc -- File does not exist.
  echo ACTION NEEDED: Cannot locate dsm.opt . Please ensure TSM client option file exists on this system and the path is correct and then rerun.
  echo Exiting ...
  exit 1
fi

if [ -f $PTCLIPATH/ptcli ]
then
  echo validating -ptclipath path -- OK.
else
  echo validating -ptclipath path $PTCLIPATH/dsmadmc -- File does not exist.
  if [ -f /opt/IBM/PTManager/ptcli ]
  then
    echo validating -ptclipath default path /opt/IBM/PTManager/ptcli -- OK.
    set PTCLIPATH=/opt/IBM/PTManager
  else
    echo validating -ptclipath default path /opt/IBM/PTManager/ptcli -- File does not exist.
    echo ACTION NEEDED: Cannot locate ptcli . Please ensure PortectTIER Manager command-line tool is installed on this system and the path is correct and then rerun.
    echo Exiting ...
    exit 1
  fi
fi

# Get server version and macro version
echo
echo Validating TSM Server version ...

PATHSAVE=`pwd`
cd $DSMADMCPATH

tmpfile=/tmp/vertmpfile
$DSMADMCPATH/dsmadmc -optfile=$DSMOPTFILE -id=$DSMADMIN -password=$DSMPASS -displ=table -dataonly=yes "select cast(VERSION as char(1))||cast(RELEASE as char(1)) as ver from status" > $tmpfile
RC=$?
if [ $RC -ne 0 ] 
then
  echo Error accessing TSM server with rc=$RC ...
  cat $tmpfile
  exit $RC
fi

TSMVER=`cat $tmpfile`
echo TSM server version: $TSMVER
rm -rf $tmpfile

MACROVER=v63
if [ "$TSMVER" \< "63" ] 
then MACROVER=v6
fi
echo Using Macro version: $MACROVER

cd $PATHSAVE

INMACRO=tsm_tb_cap_$MACROVER.macro.template
OUTMACRO=tsm_tb_cap_$MACROVER.macro
OUTFILE=tsm_tb_cap_$MACROVER.out

FULLFILENAME=$(cd "$(dirname "$0")"; pwd)/$INMACRO

PTCLIVERXML=PtcliVersion.xml
PTVERSIONXML=ServerVersion.xml
STATISTICSXML=RepositoryStatistics.xml
LIBRARIESXML=Libraries.xml
LIBINFOXML=LibInfo.xml
SNXML=LibSn.xml

if [ -f $LIBINFOXML ] ; then rm -rf $LIBINFOXML ; fi

if [ "$PRARNUM" -eq "8" ]
then
  if [ -z "$DSMADMCPATH" ] || [ -z "$DSMOPTFILE" ] || [ -z "$DSMADMIN" ] || [ -z "$DSMPASS" ] || [ -z "$MACROVER" ] || [ -z "$PTCLIPATH" ] || [ -z "$PTIPADDR" ] || [ -z "$PTUSER" ] || [ -z "$PTPASS" ] 
  then print_usage
  fi

  echo
  echo Validating ProtecTIER Manager version ...
  $PTCLIPATH/ptcli -v > $PTCLIVERXML
  RC=$?
  if [ $RC -ne 0 ] 
  then
    echo Error accessing ptcli version with rc=$RC ...
    cat $PTCLIVERXML
    exit $RC
  fi

  PTCLIVER=`grep 'release="' $PTCLIVERXML | sed 's/.*release="//' | sed 's/".*//'`
  echo ProtecTIER Server version: $PTCLIVER

  var=`echo $PTCLIVER | sed 's/\./ /g'`
  arr=($var)
  badver=0
  if [ "${arr[0]}" -lt "3" ]
  then
    badver=1
  elif [ "${arr[0]}" -eq "3" ]
  then
    if [ "${arr[1]}" -lt "3" ] 
    then
      badver=1
    elif [ "${arr[1]}" -eq "3" ]
    then
      if [ "${arr[2]}" -lt "3" ]
      then
        badver=1
      fi
    fi
  fi

  if [ $badver -eq 1 ]
  then
    echo The Capacity Measurement Tool requires ProtecTIER Manager version 3.3.3.0 or later.
    echo Exiting ...
    exit 1
  fi

  echo
  echo Validating ProtecTIER Server version ...
  $PTCLIPATH/ptcli ServerVersion --ip $PTIPADDR --loginInline $PTUSER,$PTPASS > $PTVERSIONXML
  RC=$?
  if [ $RC -ne 0 ] 
  then
    echo Error accessing ptcli ServerVersion with rc=$RC ...
    cat $PTVERSIONXML
    exit $RC
  fi

  PTVER=`grep 'pt-version="' $PTVERSIONXML | sed 's/.*pt-version="//' | sed 's/".*//'`
  echo ProtecTIER Server version: $PTVER
  
  var=`echo $PTVER | sed 's/\./ /g'`
  arr=($var)
  badver=0
  if [ "${arr[0]}" -lt "3" ]
  then
    badver=1
  elif [ "${arr[0]}" -eq "3" ]
  then
    if [ "${arr[1]}" -lt "3" ] 
    then
      badver=1
    elif [ "${arr[1]}" -eq "3" ]
    then
      if [ "${arr[2]}" -lt "3" ]
      then
        badver=1
      fi
    fi
  fi

  if [ $badver -eq 1 ]
  then
    echo The Capacity Measurement Tool requires ProtecTIER Server version 3.3.3.0 or later.
    echo Exiting ...
    exit 1
  fi
  
  echo
  echo Querying ProtecTIER ...

  # echo Query ProtecTIER for Library list
  $PTCLIPATH/ptcli Libraries --ip $PTIPADDR --loginInline $PTUSER,$PTPASS > $LIBRARIESXML
  RC=$?
  if [ $RC -ne 0 ] 
  then
    echo Error accessing ptcli Libraries with rc=$RC ...
    cat $LIBRARIESXML
    exit $RC
  fi

  grep 'serial-number' $LIBRARIESXML | sed 's/.*serial-number=//' | sed 's/>//g;s/ .*//g;s/\"//g' > $SNXML

  SNLIST=`awk '{if(NR==1){printf"l.LIBRARY_SERIAL like '\''%%%s%%'\''",$0}else{printf" or l.LIBRARY_SERIAL like '\''%%%s%%'\''",$0}}' $SNXML`
  #echo $SNLIST

else
  print_usage
fi

sed "s/SERIALNUMBER/$SNLIST/g" $FULLFILENAME > $OUTMACRO

rm -rf *.xml

echo
echo Querying TSM Server ...

# invoke dsmamdc
PATHSAVE=`pwd`
cd $DSMADMCPATH
$DSMADMCPATH/dsmadmc -optfile=$DSMOPTFILE -id=$DSMADMIN -password=$DSMPASS -displ=table -dataonly=yes -outfile=$PATHSAVE/$OUTFILE macro $PATHSAVE/$OUTMACRO
RC=$?
if [ $RC -ne 0 ] 
then
  echo Error accessing TSM server with rc=$RC ...
  cat $PATHSAVE/$OUTFILE
  exit $RC
fi

echo
echo SUR Capacity result outputs to $PATHSAVE/$OUTFILE
echo

exit 0

